/*
** Copyright (C) 1991-1995 by
** Digital Equipment Corporation, Littleton, Mass.
**
** This software is furnished under a license and may be used and copied
** only  in  accordance  with  the  terms  of such  license and with the
** inclusion of the above copyright notice. This software or  any  other
** copies thereof may not be provided or otherwise made available to any
** other person. No title to and ownership of  the  software  is  hereby
** transferred.
**
** The information in this software is subject to change without  notice
** and  should  not be  construed  as  a commitment by Digital Equipment
** Corporation.
**
** Digital assumes no responsibility for the use or  reliability  of its
** software on equipment which is not supplied by Digital.
**
*/

#include "sys/types.h"
#include "config.h"
#include "sys/dfx_space.h"

/*++
* DFX_DEBUG -
*   Debug switch that will allow driver to generate diagnostic messages.
*
* DFX_FULL_DUPLEX_ENB_DEF -
*   Enables/disables FDDI Full Duplex mode on adapter (1 == enable, 2 == disable)
*   Default is disabled.
*
* DFX_REQ_TTRT_DEF -
*   Requested Target Token Rotation Time (TTRT) in 80 nanosecond units
*   Default is 8 ms.
*
* DFX_BURST_SIZE_DEF -
*   Adapter burst length in longwords (0 == 4 LWs, 1 == 8 LWs, 2 == 16 LWs)
*   Default is 16 longwords burst.
*
* DFX_REC_BUFS_TO_POST -
*   Number of buffers pre-allocated for receive.
*
* DFX_RCV_PKTS_QUEUED_THRESH_HI -
*   # of packets queued to read queue before rcv processing is disabled
*   (used as a high-water mark to disable driver rcv processing of
*   packets from the adapter).
*
* DFX_RCV_PKTS_QUEUED_THRESH_LO -
*   When less than this # of packets are queued to read queue then
*   driver receive processing will be re-enabled if it was previously
*   disabled.
*
* DFX_BYTES_PER_BOARD -
*   # of bytes per board... Each board allows up to 32 users to be attached
*   with each user being allowed to use up to 62 multicast addresses.
*
* DFX_UNIFORM_CARD_MODEL -
*   When enabled, frames sent by a user will be looped back to the user
*   if the frame meets the perfect filter criteria for that user.  Required
*   by LLI spec, but may not be required on other UNIX implementations.
*
* DFX_MAX_BOARDS -
*   Maximum number of controllers configured in system.
--*/

#define DFX_DEBUG 			DFX_FALSE
#define DFX_FULL_DUPLEX_ENB_DEF		2
#define DFX_REQ_TTRT_DEF		100000
#define DFX_BURST_SIZE_DEF		2
#define DFX_REC_BUFS_TO_POST		8
#define DFX_RCV_PKTS_QUEUED_THRESH_HI  	16
#define DFX_RCV_PKTS_QUEUED_THRESH_LO  	8
#define DFX_BYTES_PER_BOARD		25500
#define DFX_UNIFORM_CARD_MODEL		DFX_TRUE

#ifdef DFX7_0
#define DFX_MAX_BOARDS			8	
#else
#ifdef DFX6_0
#define DFX_MAX_BOARDS			7	
#else
#ifdef DFX5_0
#define DFX_MAX_BOARDS			6	
#else
#ifdef DFX4_0
#define DFX_MAX_BOARDS			5	
#else
#ifdef DFX3_0
#define DFX_MAX_BOARDS			4	
#else
#ifdef DFX2_0
#define DFX_MAX_BOARDS			3	
#else
#ifdef DFX1_0
#define DFX_MAX_BOARDS			2	
#else
#ifdef DFX_0
#define DFX_MAX_BOARDS			1	
#endif
#endif
#endif
#endif
#endif
#endif
#endif
#endif

DFX_config_info_t DFX_info[DFX_MAX_BOARDS] =
    {
#ifdef DFX_0
        {
        0,				/* ulong 	board_num; */
        "dfx0",				/* char		*board_id; */
        0,				/* ulong	board_type; */
        0,				/* ulong	eisa_slot_num; */
        0,				/* ulong	pci_device_handle; */
        0,				/* int		int_level; */
        0,				/* int		int_mode; */
        0,				/* int		int_shared; */
        0,				/* int		port_addr_0; */
        0,				/* int		port_size_0; */
        0,				/* int		port_addr_1; */
        0,				/* int		port_size_1; */
        0,				/* uchar	*reg_base_vp; */
        0,				/* ulong	reg_base_p; */
        0,				/* ulong 	mem_map_size; */
        DFX_FULL_DUPLEX_ENB_DEF,	/* ulong 	full_duplex_enb; */
        DFX_REQ_TTRT_DEF,		/* ulong 	req_ttrt; */
        DFX_BURST_SIZE_DEF,		/* ulong 	burst_size; */
        DFX_REC_BUFS_TO_POST,		/* uchar	rec_bufs_to_post; */
        DFX_RCV_PKTS_QUEUED_THRESH_HI,	/* ulong	rcv_pkts_queued_thresh_hi; */
        DFX_RCV_PKTS_QUEUED_THRESH_LO,	/* ulong	rcv_pkts_queued_thresh_lo; */
        DFX_UNIFORM_CARD_MODEL,	   	/* int		uniform_card_model; */
#ifdef DFX_CMAJOR_0
        DFX_CMAJOR_0			/* int		major_num; */
#else
        -1				/* int		major_num; */
#endif
       }
#endif

#ifdef DFX1_0
       ,{
        1,				/* ulong 	board_num; */
        "dfx1",				/* char		*board_id; */
        0,				/* ulong	board_type; */
        0,				/* ulong	eisa_slot_num; */
        0,				/* ulong	pci_device_handle; */
        0,				/* int		int_level; */
        0,				/* int		int_mode; */
        0,				/* int		int_shared; */
        0,				/* int		port_addr_0; */
        0,				/* int		port_size_0; */
        0,				/* int		port_addr_1; */
        0,				/* int		port_size_1; */
        0,				/* uchar	*reg_base_vp; */
        0,				/* ulong	reg_base_p; */
        0,				/* ulong 	mem_map_size; */
        DFX_FULL_DUPLEX_ENB_DEF,	/* ulong 	full_duplex_enb; */
        DFX_REQ_TTRT_DEF,		/* ulong 	req_ttrt; */
        DFX_BURST_SIZE_DEF,		/* ulong 	burst_size; */
        DFX_REC_BUFS_TO_POST,		/* uchar	rec_bufs_to_post; */
        DFX_RCV_PKTS_QUEUED_THRESH_HI,	/* ulong	rcv_pkts_queued_thresh_hi; */
        DFX_RCV_PKTS_QUEUED_THRESH_LO,	/* ulong	rcv_pkts_queued_thresh_lo; */
        DFX_UNIFORM_CARD_MODEL,	   	/* int		uniform_card_model; */
#ifdef DFX_CMAJOR_1
        DFX_CMAJOR_1			/* int		major_num; */
#else
        -1				/* int		major_num; */
#endif
       }
#endif

#ifdef DFX2_0
       ,{
        2,				/* ulong 	board_num; */
        "dfx2",				/* char		*board_id; */
        0,				/* ulong	board_type; */
        0,				/* ulong	eisa_slot_num; */
        0,				/* ulong	pci_device_handle; */
        0,				/* int		int_level; */
        0,				/* int		int_mode; */
        0,				/* int		int_shared; */
        0,				/* int		port_addr_0; */
        0,				/* int		port_size_0; */
        0,				/* int		port_addr_1; */
        0,				/* int		port_size_1; */
        0,				/* uchar	*reg_base_vp; */
        0,				/* ulong	reg_base_p; */
        0,				/* ulong 	mem_map_size; */
        DFX_FULL_DUPLEX_ENB_DEF,	/* ulong 	full_duplex_enb; */
        DFX_REQ_TTRT_DEF,		/* ulong 	req_ttrt; */
        DFX_BURST_SIZE_DEF,		/* ulong 	burst_size; */
        DFX_REC_BUFS_TO_POST,		/* uchar	rec_bufs_to_post; */
        DFX_RCV_PKTS_QUEUED_THRESH_HI,	/* ulong	rcv_pkts_queued_thresh_hi; */
        DFX_RCV_PKTS_QUEUED_THRESH_LO,	/* ulong	rcv_pkts_queued_thresh_lo; */
        DFX_UNIFORM_CARD_MODEL,	   	/* int		uniform_card_model; */
#ifdef DFX_CMAJOR_2
        DFX_CMAJOR_2			/* int		major_num; */
#else
        -1				/* int		major_num; */
#endif
       }
#endif

#ifdef DFX3_0
       ,{
        3,				/* ulong 	board_num; */
        "dfx3",				/* char		*board_id; */
        0,				/* ulong	board_type; */
        0,				/* ulong	eisa_slot_num; */
        0,				/* ulong	pci_device_handle; */
        0,				/* int		int_level; */
        0,				/* int		int_mode; */
        0,				/* int		int_shared; */
        0,				/* int		port_addr_0; */
        0,				/* int		port_size_0; */
        0,				/* int		port_addr_1; */
        0,				/* int		port_size_1; */
        0,				/* uchar	*reg_base_vp; */
        0,				/* ulong	reg_base_p; */
        0,				/* ulong 	mem_map_size; */
        DFX_FULL_DUPLEX_ENB_DEF,	/* ulong 	full_duplex_enb; */
        DFX_REQ_TTRT_DEF,		/* ulong 	req_ttrt; */
        DFX_BURST_SIZE_DEF,		/* ulong 	burst_size; */
        DFX_REC_BUFS_TO_POST,		/* uchar	rec_bufs_to_post; */
        DFX_RCV_PKTS_QUEUED_THRESH_HI,	/* ulong	rcv_pkts_queued_thresh_hi; */
        DFX_RCV_PKTS_QUEUED_THRESH_LO,	/* ulong	rcv_pkts_queued_thresh_lo; */
        DFX_UNIFORM_CARD_MODEL,	   	/* int		uniform_card_model; */
#ifdef DFX_CMAJOR_3
        DFX_CMAJOR_3			/* int		major_num; */
#else
        -1				/* int		major_num; */
#endif
       }
#endif

#ifdef DFX4_0
       ,{
        4,				/* ulong 	board_num; */
        "dfx4",				/* char		*board_id; */
        0,				/* ulong	board_type; */
        0,				/* ulong	eisa_slot_num; */
        0,				/* ulong	pci_device_handle; */
        0,				/* int		int_level; */
        0,				/* int		int_mode; */
        0,				/* int		int_shared; */
        0,				/* int		port_addr_0; */
        0,				/* int		port_size_0; */
        0,				/* int		port_addr_1; */
        0,				/* int		port_size_1; */
        0,				/* uchar	*reg_base_vp; */
        0,				/* ulong	reg_base_p; */
        0,				/* ulong 	mem_map_size; */
        DFX_FULL_DUPLEX_ENB_DEF,	/* ulong 	full_duplex_enb; */
        DFX_REQ_TTRT_DEF,		/* ulong 	req_ttrt; */
        DFX_BURST_SIZE_DEF,		/* ulong 	burst_size; */
        DFX_REC_BUFS_TO_POST,		/* uchar	rec_bufs_to_post; */
        DFX_RCV_PKTS_QUEUED_THRESH_HI,	/* ulong	rcv_pkts_queued_thresh_hi; */
        DFX_RCV_PKTS_QUEUED_THRESH_LO,	/* ulong	rcv_pkts_queued_thresh_lo; */
        DFX_UNIFORM_CARD_MODEL,	   	/* int		uniform_card_model; */
#ifdef DFX_CMAJOR_4
        DFX_CMAJOR_4			/* int		major_num; */
#else
        -1				/* int		major_num; */
#endif
       }
#endif

#ifdef DFX5_0
       ,{
        5,				/* ulong 	board_num; */
        "dfx5",				/* char		*board_id; */
        0,				/* ulong	board_type; */
        0,				/* ulong	eisa_slot_num; */
        0,				/* ulong	pci_device_handle; */
        0,				/* int		int_level; */
        0,				/* int		int_mode; */
        0,				/* int		int_shared; */
        0,				/* int		port_addr_0; */
        0,				/* int		port_size_0; */
        0,				/* int		port_addr_1; */
        0,				/* int		port_size_1; */
        0,				/* uchar	*reg_base_vp; */
        0,				/* ulong	reg_base_p; */
        0,				/* ulong 	mem_map_size; */
        DFX_FULL_DUPLEX_ENB_DEF,	/* ulong 	full_duplex_enb; */
        DFX_REQ_TTRT_DEF,		/* ulong 	req_ttrt; */
        DFX_BURST_SIZE_DEF,		/* ulong 	burst_size; */
        DFX_REC_BUFS_TO_POST,		/* uchar	rec_bufs_to_post; */
        DFX_RCV_PKTS_QUEUED_THRESH_HI,	/* ulong	rcv_pkts_queued_thresh_hi; */
        DFX_RCV_PKTS_QUEUED_THRESH_LO,	/* ulong	rcv_pkts_queued_thresh_lo; */
        DFX_UNIFORM_CARD_MODEL,	   	/* int		uniform_card_model; */
#ifdef DFX_CMAJOR_5
        DFX_CMAJOR_5			/* int		major_num; */
#else
        -1				/* int		major_num; */
#endif
       }
#endif

#ifdef DFX6_0
       ,{
        6,				/* ulong 	board_num; */
        "dfx6",				/* char		*board_id; */
        0,				/* ulong	board_type; */
        0,				/* ulong	eisa_slot_num; */
        0,				/* ulong	pci_device_handle; */
        0,				/* int		int_level; */
        0,				/* int		int_mode; */
        0,				/* int		int_shared; */
        0,				/* int		port_addr_0; */
        0,				/* int		port_size_0; */
        0,				/* int		port_addr_1; */
        0,				/* int		port_size_1; */
        0,				/* uchar	*reg_base_vp; */
        0,				/* ulong	reg_base_p; */
        0,				/* ulong 	mem_map_size; */
        DFX_FULL_DUPLEX_ENB_DEF,	/* ulong 	full_duplex_enb; */
        DFX_REQ_TTRT_DEF,		/* ulong 	req_ttrt; */
        DFX_BURST_SIZE_DEF,		/* ulong 	burst_size; */
        DFX_REC_BUFS_TO_POST,		/* uchar	rec_bufs_to_post; */
        DFX_RCV_PKTS_QUEUED_THRESH_HI,	/* ulong	rcv_pkts_queued_thresh_hi; */
        DFX_RCV_PKTS_QUEUED_THRESH_LO,	/* ulong	rcv_pkts_queued_thresh_lo; */
        DFX_UNIFORM_CARD_MODEL,	   	/* int		uniform_card_model; */
#ifdef DFX_CMAJOR_6
        DFX_CMAJOR_6			/* int		major_num; */
#else
        -1				/* int		major_num; */
#endif
       }
#endif

#ifdef DFX7_0
       ,{
        7,				/* ulong 	board_num; */
        "dfx7",				/* char		*board_id; */
        0,				/* ulong	board_type; */
        0,				/* ulong	eisa_slot_num; */
        0,				/* ulong	pci_device_handle; */
        0,				/* int		int_level; */
        0,				/* int		int_mode; */
        0,				/* int		int_shared; */
        0,				/* int		port_addr_0; */
        0,				/* int		port_size_0; */
        0,				/* int		port_addr_1; */
        0,				/* int		port_size_1; */
        0,				/* uchar	*reg_base_vp; */
        0,				/* ulong	reg_base_p; */
        0,				/* ulong 	mem_map_size; */
        DFX_FULL_DUPLEX_ENB_DEF,	/* ulong 	full_duplex_enb; */
        DFX_REQ_TTRT_DEF,		/* ulong 	req_ttrt; */
        DFX_BURST_SIZE_DEF,		/* ulong 	burst_size; */
        DFX_REC_BUFS_TO_POST,		/* uchar	rec_bufs_to_post; */
        DFX_RCV_PKTS_QUEUED_THRESH_HI,	/* ulong	rcv_pkts_queued_thresh_hi; */
        DFX_RCV_PKTS_QUEUED_THRESH_LO,	/* ulong	rcv_pkts_queued_thresh_lo; */
        DFX_UNIFORM_CARD_MODEL,	   	/* int		uniform_card_model; */
#ifdef DFX_CMAJOR_7
        DFX_CMAJOR_7			/* int		major_num; */
#else
        -1				/* int		major_num; */
#endif
       }
#endif

    };

#ifndef TCP_0
    void *ifstats = (void *)0;
#endif


int 	DFX_board_num_to_ptr[DFX_MAX_BOARDS];
ushort	DFX_debug = DFX_DEBUG;
int	DFX_max_boards = DFX_MAX_BOARDS;
int	DFX_bytes_per_board = DFX_BYTES_PER_BOARD;
ulong	DFX_board[(DFX_MAX_BOARDS*DFX_BYTES_PER_BOARD)/4 + 1];
